Mirador module:
------------------------
Requires - Drupal 8
Compiled Mirador javascript library
IIIF [Image API](http://iiif.io/api/image/2.0/) server


Overview:
--------
Mirador is a multi-repository, configurable, extensible, and easy-to-integrate
viewer and annotation creation and comparison environment for IIIF resources,
ranging from deep-zooming artwork, to complex manuscript objects. It provides a
tiling windowed environment for comparing multiple image-based resources,
synchronised structural and visual navigation of content using openSeadragon,
Open Annotation compliant annotation creation and viewing on deep-zoomable
canvases, metadata display, bookreading, and bookmarking.
This module allows for integration of Mirador into Drupal.

* Mirador - https://github.com/IIIF/mirador


Features:
---------

The Mirador module:

* Works as a Field Formatter in entities.
* Provides annotation capabilities in the images.
* Mirador module provides a image field formatter and a text field formatter
  named as mirador.
* You can set the field formatter in the "Manage display" of your entity.
  Eg: /admin/structure/types/manage/article/display.
* In the field formatter a setting option is available to map the field values.
  These field values will be used to generate the metadata of the mirador viewer.

The Mirador plugin:

* Mirador implements the full client functionality of the IIIF Image and Presentation APIs.
* It provides tools for bringing in metadata, images, structures, and can create, edit, delete, and view
  annotations in Open Annotation Format.
* Appearance is controlled through CSS so it can be restyled.
* Mobile friendly.



Installation:
------------
1. Install the module as normal, see link for instructions.
   Link: https://www.drupal.org/documentation/install/modules-themes/modules-8
2. Download compiled Mirador javascript library
   (https://github.com/NVLI/mirador-js/archive/master.zip) into Drupal's libraries
   directory (Create one, if libraries directory is not present). Verify the file permission is web servable. Make sure the path to the plugin is libraries/mirador/mirador.js.
3. Set the IIIF image server in path /admin/config/media/mirador.
   In the image server specify the path upto files directory, in simple resolver
   config.
4. For textfield Mirador formatter, enter the image identifier in the text field. The image identifier
   should be the image path from files directory. The absolute path upto files directory will be specified in
   IIIF server.
5. Mirador module also provides annotation capability to the images.
6. To add annotation, visit the config /admin/config/media/mirador. User can add their own custom endpoints.
7. Mirador module comes with a mirador_annotation module for those who does not want to use custom endpoints.


Working:
-------

Image Field Formatter

1. Set the field formatter as mirador for the image field,
   for the entity type you wish to display mirador viewer.
   This setting will be available in the  "Manage Display" of the fields for that entity type.
2. Set the field mapping for the metadata in the settings form near to the "Format" option.
3. Once a entity against this entity type is viewed, the mirador-load.js will initiate,
   a manifest file will be generated by the system, with the provided image and metadata.
   This manifest file will be passed to mirador.js, The image then will then be loaded via IIIF
   server provided in the configuration.
4. These images will be cached by the IIIF Server. The cache directory location
   can be specified in the IIIF Server configuration.


Text Field Formatter

1. Set the field formatter as mirador for the text field, for the entity type you
   wish to display mirador viewer. This setting will be available in the  "Manage Display"
   of the fields for that entity type.
2. Set the field mapping for the metadata in the settings form near to the "Format" option.
3. On creating the entity against this entity type, specify the image path in the mirador field.
   the image path, should be the path from that is set in IIIF Server.
4. On viewing the entity, The mirador-load.js will initiate,
   a manifest file will be generated by the system, with the provided image and metadata.
   This manifest file will be passed to mirador.js, The image then will be loaded via IIIF
   server provided in the configuration.
5. These images will be cached by the IIIF Server. The cache directory location
   can be specified in the IIIF Server configuration.

Annotation

Custom End Point

1. Go to /admin/config/media/mirador
2. Set the  Annotation Endpoint as "Custom End Point"
3. Create Endpoint
    a. Set the endpoint url.
    b. Set the Create Method.
    c. For create endpoint, Mirador provides the following data in request object.
        i. uri -> The resource uri. That is the uri of the image entity, which is being annotated.
        ii. text -> The annotation text.
        iii. data -> The annotation data in json format.
        iv. media -> The media type. In this case image.
    d. The create endpoint expects the complete created entity back as json response. With id in the entity.
4. Update/Delete Endpoint
    a. Set the endpoint url.
    b. Use token {annotation_id}, for specifying the annotation ID, in url.
       Mirador will replace it with annotation id.
    b. Set the update method.
    c. For update endpoint, Mirador provides the following data in request object.
         i. uri -> The resource uri. That is the uri of the image entity, which is being annotated.
        ii. text -> The annotation text.
        iii. data -> The annotation data in json format.
        iv. media -> The media type. In this case image.
    d. The delete endpoint provides nothing  the id in request object.
    e. The update/delete endpoint expects nothing back as response.
5. Set the permission "Perform annotation operation". This will disable the annotate buttons
   in the viewer for those without permission to annotate.

REST Endpoint.

1. Create a entity type to store the annotation data.
2. Create necessary fields in the entity type to store the annotation data.
3. Enable "rest" module available in core.
4. /admin/config/media/mirador enable "Rest endpoint".
4. Add the entity type data in settings available at /admin/config/media/mirador.
5. Add field mappings, so that system knows where all to store the data in the
   provided entity type.
6. Add proper permissions for content creation/update/view/delete of the created entity type
7. Add proper permissions for REST Webservice.
8. Set the permission "Perform annotation operation". This will disable the annotate buttons
   in the viewer for those without permission to annotate.




Configuration:
-------------
Go to "Configuration" -> "Media" -> "Mirador" to find
all the configuration options.
